api

package
v0.5.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var WriteErrorResponse = httpresponse.WriteErrorResponse

WriteErrorResponse writes an S3 error response in XML format. It is exported so that middleware can use it for validation errors.

var WriteXMLResponse = httpresponse.WriteXMLResponse

WriteXMLResponse writes an S3 response in XML format. It is exported so that middleware can use it.

Functions

This section is empty.

Types

type Handler

type Handler struct {
	S3Handler *s3.HTTPHandler
	// contains filtered or unexported fields
}

Handler handles S3 API requests

func New

func New(
	serviceFactory *service.ServicesFactory,
	authHandler *auth.Authenticator,
	urlBuilder URLBuilder,
) *Handler

New creates a new DirIO API handler

type URLBuilder

type URLBuilder interface {
	BucketURL(r *http.Request, bucket string) string
	ObjectURL(r *http.Request, bucket, key string) string
}

URLBuilder defines the interface for generating URLs in S3 API responses

Directories

Path Synopsis
Package iam is reserved for native DirIO IAM HTTP handlers.
Package iam is reserved for native DirIO IAM HTTP handlers.

Jump to