Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var WriteErrorResponse = httpresponse.WriteErrorResponse
WriteErrorResponse writes an S3 error response in XML format. It is exported so that middleware can use it for validation errors.
var WriteXMLResponse = httpresponse.WriteXMLResponse
WriteXMLResponse writes an S3 response in XML format. It is exported so that middleware can use it.
Functions ¶
This section is empty.
Types ¶
type Handler ¶
type Handler struct {
S3Handler *s3.HTTPHandler
// contains filtered or unexported fields
}
Handler handles S3 API requests
func New ¶
func New( serviceFactory *service.ServicesFactory, authHandler *auth.Authenticator, urlBuilder URLBuilder, ) *Handler
New creates a new DirIO API handler
Click to show internal directories.
Click to hide internal directories.